diff libpurple/protocols/qq/buddy_status.h @ 15822:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents 5fe8042783c1
children 44b4e8bd759b
line wrap: on
line diff
--- a/libpurple/protocols/qq/buddy_status.h	Mon Mar 19 06:11:46 2007 +0000
+++ b/libpurple/protocols/qq/buddy_status.h	Mon Mar 19 07:01:17 2007 +0000
@@ -1,9 +1,9 @@
 /**
  * @file buddy_status.h
  *
- * gaim
+ * purple
  *
  * Gaim is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
  *
@@ -53,10 +53,10 @@
 gboolean is_online(guint8 status);
 
 gint qq_buddy_status_read(guint8 *data, guint8 **cursor, gint len, qq_buddy_status *s);
-gint get_icon_offset(GaimConnection *gc);
+gint get_icon_offset(PurpleConnection *gc);
 
-void qq_send_packet_change_status(GaimConnection *gc);
+void qq_send_packet_change_status(PurpleConnection *gc);
 
-void qq_process_change_status_reply(guint8 *buf, gint buf_len, GaimConnection *gc);
-void qq_process_friend_change_status(guint8 *buf, gint buf_len, GaimConnection *gc);
+void qq_process_change_status_reply(guint8 *buf, gint buf_len, PurpleConnection *gc);
+void qq_process_friend_change_status(guint8 *buf, gint buf_len, PurpleConnection *gc);
 #endif
@@ -1,9 +1,9 @@
  *
- * Gaim is the legal property of its developers, whose names are too numerous
+ * Purple is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.